// Copyright (c) KaivnD
// Distributed under the terms of the Modified BSD License.

// (() => {
//   const head = document.querySelector('head');
//   const overrideStyles = document.createElement('style');
//   overrideStyles.innerText = `
//     .cell-output-ipywidget-background {
//       background: none !important;
//     }
//     `;
//   head?.appendChild(overrideStyles);
// })();

export * from './version';
export * from './widget';
